Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3775)

Unified Diff: chrome/browser/shell_integration_win.cc

Issue 11359133: Add default icon to app_host.exe, and use it in shortcuts during installation. (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Small comment change. Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/shell_integration_win.cc
diff --git a/chrome/browser/shell_integration_win.cc b/chrome/browser/shell_integration_win.cc
index 32790758ac80e8dca1611102a0d4ba660584e21b..16ab7486f3489cb538817115dc792d342c7fc258 100644
--- a/chrome/browser/shell_integration_win.cc
+++ b/chrome/browser/shell_integration_win.cc
@@ -425,20 +425,18 @@ string16 ShellIntegration::GetAppListAppModelIdForProfile(
profile_path);
}
-string16 ShellIntegration::GetChromiumIconPath() {
- // Determine the app path. If we can't determine what that is, we have
- // bigger fish to fry...
- FilePath app_path;
- if (!PathService::Get(base::FILE_EXE, &app_path)) {
+string16 ShellIntegration::GetChromiumIconString() {
+ // Determine the path to chrome.exe. If we can't determine what that is,
+ // we have bigger fish to fry...
+ FilePath chrome_exe;
+ if (!PathService::Get(base::FILE_EXE, &chrome_exe)) {
NOTREACHED();
return string16();
}
- string16 icon_path(app_path.value());
- icon_path.push_back(',');
- icon_path += base::IntToString16(
+ return ShellUtil::GetIconString(
+ chrome_exe.value(),
BrowserDistribution::GetDistribution()->GetIconIndex());
- return icon_path;
}
void ShellIntegration::MigrateChromiumShortcuts() {

Powered by Google App Engine
This is Rietveld 408576698